==> jc-1.4.0.tar.gz: java/sql/BatchUpdateException.h <==
// public class java.sql.BatchUpdateException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 433da070d534beae java_sql_BatchUpdateException
// @dep_class d5428f1f1b6fb1d3 java_sql_SQLException

// header file dependencies
// @dep_header java_sql_SQLException

#include "java/sql/SQLException.h"

#ifndef _JC_java_sql_BatchUpdateException_H_
#define _JC_java_sql_BatchUpdateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_sql_BatchUpdateException$sub_refs	_jc_java_sql_BatchUpdateException$sub_refs;
typedef struct _jc_java_sql_BatchUpdateException$sub_nonrefs	_jc_java_sql_BatchUpdateException$sub_nonrefs;
typedef struct _jc_java_sql_BatchUpdateException$refs	_jc_java_sql_BatchUpdateException$refs;
typedef struct _jc_java_sql_BatchUpdateException$nonrefs	_jc_java_sql_BatchUpdateException$nonrefs;
typedef struct _jc_java_sql_BatchUpdateException$object	_jc_java_sql_BatchUpdateException$object;

typedef struct _jc_java_sql_BatchUpdateException$fields_struct	_jc_java_sql_BatchUpdateException$fields_struct;
typedef const struct _jc_java_sql_BatchUpdateException$vmethods	_jc_java_sql_BatchUpdateException$vmethods;
typedef const struct _jc_java_sql_BatchUpdateException$vtable	_jc_java_sql_BatchUpdateException$vtable;
typedef const struct _jc_java_sql_BatchUpdateException$vtype	_jc_java_sql_BatchUpdateException$vtype;

// Class fields structure
struct _jc_java_sql_BatchUpdateException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_sql_BatchUpdateException$fields_struct _jc_java_sql_BatchUpdateException$class_fields;

// Constructors
extern void _jc_java_sql_BatchUpdateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *);
extern void _jc_java_sql_BatchUpdateException$method$_init$603361547accf908(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint, struct _jc_int_array *);
extern void _jc_java_sql_BatchUpdateException$method$_init$bfa3c5aaa4c2c2e6(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_int_array *);
extern void _jc_java_sql_BatchUpdateException$method$_init$e6cbc25012a7ec8e(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *, struct _jc_java_lang_String$object *, struct _jc_int_array *);
extern void _jc_java_sql_BatchUpdateException$method$_init$dbf53d65c126dfa3(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *, struct _jc_int_array *);

// Virtual methods
extern _jc_int_array *_jc_java_sql_BatchUpdateException$method$getUpdateCounts$7498ecd987ed35cf(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_sql_BatchUpdateException$method_info$getUpdateCounts$7498ecd987ed35cf;

// Virtual methods structure
struct _jc_java_sql_BatchUpdateException$vmethods {
	_jc_int_array	*(*getUpdateCounts$7498ecd987ed35cf)(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *);
};

// Vtable
struct _jc_java_sql_BatchUpdateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_sql_SQLException$vmethods	java_sql_SQLException;
	_jc_java_sql_BatchUpdateException$vmethods	java_sql_BatchUpdateException;
};

// Vtype
struct _jc_java_sql_BatchUpdateException$vtype {
	_jc_type			type;
	_jc_java_sql_BatchUpdateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_BatchUpdateException$sub_refs {
	_jc_int_array	*updateCounts;
};

// Reference instance fields (object)
struct _jc_java_sql_BatchUpdateException$refs {
    _jc_java_sql_BatchUpdateException$sub_refs	java_sql_BatchUpdateException;
    _jc_java_sql_SQLException$sub_refs	java_sql_SQLException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_BatchUpdateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_sql_BatchUpdateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_sql_SQLException$sub_nonrefs	java_sql_SQLException;
    _jc_java_sql_BatchUpdateException$sub_nonrefs	java_sql_BatchUpdateException;
};

// Object instance structure
struct _jc_java_sql_BatchUpdateException$object {
	_jc_java_sql_BatchUpdateException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_BatchUpdateException$vtype	*vtype;
	_jc_java_sql_BatchUpdateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_BatchUpdateException$vtype _jc_java_sql_BatchUpdateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_BatchUpdateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_BatchUpdateException$class_object;

#endif	/* _JC_java_sql_BatchUpdateException_H_ */

==> jc-1.4.6.tar.gz: java/sql/BatchUpdateException.h <==
// public class java.sql.BatchUpdateException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 433da070d534beae java_sql_BatchUpdateException
// @dep_class d5428f1f1b6fb1d3 java_sql_SQLException

// header file dependencies
// @dep_header java_sql_SQLException

#include "java/sql/SQLException.h"

#ifndef _JC_java_sql_BatchUpdateException_H_
#define _JC_java_sql_BatchUpdateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_sql_BatchUpdateException$sub_refs	_jc_java_sql_BatchUpdateException$sub_refs;
typedef struct _jc_java_sql_BatchUpdateException$sub_nonrefs	_jc_java_sql_BatchUpdateException$sub_nonrefs;
typedef struct _jc_java_sql_BatchUpdateException$refs	_jc_java_sql_BatchUpdateException$refs;
typedef struct _jc_java_sql_BatchUpdateException$nonrefs	_jc_java_sql_BatchUpdateException$nonrefs;
typedef struct _jc_java_sql_BatchUpdateException$object	_jc_java_sql_BatchUpdateException$object;

typedef struct _jc_java_sql_BatchUpdateException$fields_struct	_jc_java_sql_BatchUpdateException$fields_struct;
typedef const struct _jc_java_sql_BatchUpdateException$vmethods	_jc_java_sql_BatchUpdateException$vmethods;
typedef const struct _jc_java_sql_BatchUpdateException$vtable	_jc_java_sql_BatchUpdateException$vtable;
typedef const struct _jc_java_sql_BatchUpdateException$vtype	_jc_java_sql_BatchUpdateException$vtype;

// Class fields structure
struct _jc_java_sql_BatchUpdateException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_sql_BatchUpdateException$fields_struct _jc_java_sql_BatchUpdateException$class_fields;

// Constructors
extern void _jc_java_sql_BatchUpdateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_BatchUpdateException$method$_init$603361547accf908(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint, struct _jc_int_array *) _JC_JCNI_ATTR;
extern void _jc_java_sql_BatchUpdateException$method$_init$bfa3c5aaa4c2c2e6(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_int_array *) _JC_JCNI_ATTR;
extern void _jc_java_sql_BatchUpdateException$method$_init$e6cbc25012a7ec8e(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *, struct _jc_java_lang_String$object *, struct _jc_int_array *) _JC_JCNI_ATTR;
extern void _jc_java_sql_BatchUpdateException$method$_init$dbf53d65c126dfa3(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *, struct _jc_int_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_int_array *_jc_java_sql_BatchUpdateException$method$getUpdateCounts$7498ecd987ed35cf(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_sql_BatchUpdateException$method_info$getUpdateCounts$7498ecd987ed35cf;

// Virtual methods structure
struct _jc_java_sql_BatchUpdateException$vmethods {
	_jc_int_array	*(*getUpdateCounts$7498ecd987ed35cf)(_jc_env *, struct _jc_java_sql_BatchUpdateException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_sql_BatchUpdateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_sql_SQLException$vmethods	java_sql_SQLException;
	_jc_java_sql_BatchUpdateException$vmethods	java_sql_BatchUpdateException;
};

// Vtype
struct _jc_java_sql_BatchUpdateException$vtype {
	_jc_type			type;
	_jc_java_sql_BatchUpdateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_BatchUpdateException$sub_refs {
	_jc_int_array	*updateCounts;
};

// Reference instance fields (object)
struct _jc_java_sql_BatchUpdateException$refs {
    _jc_java_sql_BatchUpdateException$sub_refs	java_sql_BatchUpdateException;
    _jc_java_sql_SQLException$sub_refs	java_sql_SQLException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_BatchUpdateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_sql_BatchUpdateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_sql_SQLException$sub_nonrefs	java_sql_SQLException;
    _jc_java_sql_BatchUpdateException$sub_nonrefs	java_sql_BatchUpdateException;
};

// Object instance structure
struct _jc_java_sql_BatchUpdateException$object {
	_jc_java_sql_BatchUpdateException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_BatchUpdateException$vtype	*vtype;
	_jc_java_sql_BatchUpdateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_BatchUpdateException$vtype _jc_java_sql_BatchUpdateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_BatchUpdateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_BatchUpdateException$class_object;

#endif	/* _JC_java_sql_BatchUpdateException_H_ */
